@@ -45,7 +45,7 @@ impl HttpHandler {
 
         if !req_p.exists() || (symlink && !self.follow_symlinks) ||
            (symlink && self.follow_symlinks && self.sandbox_symlinks && !is_descendant_of(&req_p, &self.hosted_directory.1)) {
-            return self.handle_nonexistant(req, req_p);
+            return self.handle_nonexistent(req, req_p);
         }
 
 
@@ -66,8 +66,8 @@ impl HttpHandler {
                 } {
                     Ok(e) => {
                         log!(self.log,
-                             "{green}{}{reset} tried to {red}PROPFIND{reset} {yellow}{}{reset} with invalid XML",
-                             req.remote_addr,
+                             "{} tried to {red}PROPFIND{reset} {yellow}{}{reset} with invalid XML",
+                             self.remote_addresses(&req),
                              req_p.display());
                         return self.handle_generated_response_encoding(req,
                                                                        status::BadRequest,
@@ -79,8 +79,8 @@ impl HttpHandler {
         };
 
         log!(self.log,
-             "{green}{}{reset} requested {red}PROPFIND{reset} of {} on {yellow}{}{reset} at depth {}",
-             req.remote_addr,
+             "{} requested {red}PROPFIND{reset} of {} on {yellow}{}{reset} at depth {}",
+             self.remote_addresses(&req),
              props,
              req_p.display(),
              depth);
@@ -146,7 +146,12 @@ impl HttpHandler {
                 let mut symlink = false;
                 while let Ok(newlink) = path.read_link() {
                     symlink = true;
-                    path = newlink;
+                    if newlink.is_absolute() {
+                        path = newlink;
+                    } else {
+                        path.pop();
+                        path.push(newlink);
+                    }
                 }
 
                 if !(!path.exists() || (symlink && !self.follow_symlinks) ||
@@ -179,15 +184,15 @@ impl HttpHandler {
 
         if !req_p.exists() || (symlink && !self.follow_symlinks) ||
            (symlink && self.follow_symlinks && self.sandbox_symlinks && !is_descendant_of(&req_p, &self.hosted_directory.1)) {
-            return self.handle_nonexistant(req, req_p);
+            return self.handle_nonexistent(req, req_p);
         }
 
         let props = match parse_proppatch(req) {
             Ok(props) => props,
             Err(e) => {
                 log!(self.log,
-                     "{green}{}{reset} tried to {red}PROPPATCH{reset} {yellow}{}{reset} with invalid XML",
-                     req.remote_addr,
+                     "{} tried to {red}PROPPATCH{reset} {yellow}{}{reset} with invalid XML",
+                     self.remote_addresses(&req),
                      req_p.display());
                 return self.handle_generated_response_encoding(req,
                                                                status::BadRequest,
@@ -196,8 +201,8 @@ impl HttpHandler {
         };
 
         log!(self.log,
-             "{green}{}{reset} requested {red}PROPPATCH{reset} of {} on {yellow}{}{reset}",
-             req.remote_addr,
+             "{} requested {red}PROPPATCH{reset} of {} on {yellow}{}{reset}",
+             self.remote_addresses(&req),
              CommaList(props.iter().map(|p| &p.0.local_name)),
              req_p.display());
 
@@ -211,8 +216,8 @@ impl HttpHandler {
         let (req_p, symlink, url_err) = self.parse_requested_path(req);
 
         log!(self.log,
-             "{green}{}{reset} requested to {red}MKCOL{reset} at {yellow}{}{reset}",
-             req.remote_addr,
+             "{} requested to {red}MKCOL{reset} at {yellow}{}{reset}",
+             self.remote_addresses(&req),
              req_p.display());
 
         if url_err {
@@ -225,7 +230,7 @@ impl HttpHandler {
 
         if !req_p.parent().map(|pp| pp.exists()).unwrap_or(true) || (symlink && !self.follow_symlinks) ||
            (symlink && self.follow_symlinks && self.sandbox_symlinks && !is_descendant_of(&req_p, &self.hosted_directory.1)) {
-            return self.handle_nonexistant_status(req, req_p, status::Conflict);
+            return self.handle_nonexistent_status(req, req_p, status::Conflict);
         }
 
         if req.body.read_exact(&mut [0]).is_ok() {
@@ -236,7 +241,7 @@ impl HttpHandler {
             Ok(()) => Ok(Response::with(status::Created)),
             Err(e) => {
                 match e.kind() {
-                    IoErrorKind::NotFound => self.handle_nonexistant_status(req, req_p, status::Conflict),
+                    IoErrorKind::NotFound => self.handle_nonexistent_status(req, req_p, status::Conflict),
                     IoErrorKind::AlreadyExists => Ok(Response::with((status::MethodNotAllowed, "File exists"))),
                     _ => Ok(Response::with(status::Forbidden)),
                 }
@@ -286,15 +291,15 @@ impl HttpHandler {
 
                 (dest_p, dest_symlink)
             }
-            None => return self.handle_invalid_url(req, "<p>Destination URL invalid or nonexistant.</p>"),
+            None => return self.handle_invalid_url(req, "<p>Destination URL invalid or nonexistent.</p>"),
         };
 
         let depth = req.headers.get::<Depth>().copied().unwrap_or(Depth::Infinity);
         let overwrite = req.headers.get::<Overwrite>().copied().unwrap_or_default().0;
 
         log!(self.log,
-             "{green}{}{reset} requested to {}{red}{}{reset} {yellow}{}{reset} to {yellow}{}{reset} at depth {}",
-             req.remote_addr,
+             "{} requested to {}{red}{}{reset} {yellow}{}{reset} to {yellow}{}{reset} at depth {}",
+             self.remote_addresses(&req),
              if overwrite { "overwrite-" } else { "" },
              if !is_move { "COPY" } else { "MOVE" },
              req_p.display(),
@@ -311,7 +316,7 @@ impl HttpHandler {
 
         if !req_p.exists() || (symlink && !self.follow_symlinks) ||
            (symlink && self.follow_symlinks && self.sandbox_symlinks && !is_descendant_of(&req_p, &self.hosted_directory.1)) {
-            return self.handle_nonexistant(req, req_p);
+            return self.handle_nonexistent(req, req_p);
         }
 
         if !dest_p.parent().map(|pp| pp.exists()).unwrap_or(true) || (dest_symlink && !self.follow_symlinks) ||
